@@ -33,15 +33,16 @@ FONT_PROPERTIES: Dict[str, Optional[Dict[str, Union[str, int]]]] = {
     'bold': {weight: bold},
     'bold_italic': {weight: bold, slant: italic},
     'bullet': None,
-    'equation_char': {weight: bold, fg: '#53f500'},
+    'equation_char': {weight: bold, fg: '#19b70a'},
     'equation_inside': {slant: italic, fg: '#ffa450'},
+    'error': {fg: '#ff6b68'},
     'h1': {size: 2, weight: bold, spacing3: 1},
     'italic': {slant: italic},
     'link': {weight: bold, fg: '#ff02a6'},
     'normal': {},
     'repeated_tag': {slant: italic, fg: '#ff002b'},
     'repeated_word': {weight: bold},
-    'tex_command': {fg: '#12d0f6'},
+    'tex_command': {fg: '#09accb'},
     'tex_argument': {fg: '#999999'},
     'underlined': {underline: True, spacing3: 1}
 }
