@@ -264,7 +264,6 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\hat{\\phantom{x}}', '̂'),
     ('\\hbar', 'ℏ'),
     ('\\heartsuit', '♡'),
-    ('\\hl', ''),
     ('\\hookleftarrow', '↩'),
     ('\\hookrightarrow', '↪'),
     ('\\iddots', '⋰'),
@@ -869,6 +868,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\wr', '≀'),
     ('\\Xi', 'Ξ'),
     ('\\xi', 'ξ'),
+    ('\\xspace', ' '),
     ('\\Yup', '⅄'),
     ('\\zeta', 'ζ')
 ]
