@@ -17,7 +17,6 @@ __all__ = [
     'process_inputs',
     'process_items',
     'process_labels',
-    'process_quotes',
     'process_ref',
     'remove_commands_char',
     'remove_commands_param',
@@ -37,7 +36,7 @@ import os
 import pydetex.utils as ut
 
 from pydetex._symbols import *
-from typing import List, Tuple, Union, Optional
+from typing import List, Tuple, Union, Optional, Callable
 
 # Files
 _LAST_NOT_FOUND_FILES_PATH = [os.getcwd()]
@@ -193,9 +192,9 @@ def remove_tag(s: str, tagname: str) -> str:
 
 
 def remove_common_tags(
-        s: str,
-        replace_tags: Optional[List] = None,
-        **kwargs
+    s: str,
+    replace_tags: Optional[List] = None,
+    **kwargs
 ) -> str:
     """
     Remove common tags from string.
@@ -229,11 +228,11 @@ def remove_common_tags(
 
 
 def process_cite(
-        s: str,
-        sort_cites: bool = True,
-        compress_cite: bool = True,
-        cite_separator: str = ', ',
-        **kwargs
+    s: str,
+    sort_cites: bool = True,
+    compress_cite: bool = True,
+    cite_separator: str = ', ',
+    **kwargs
 ) -> str:
     """
     Transforms all cites to a text-based with numbers. For example:
@@ -247,7 +246,7 @@ def process_cite(
     """
     assert isinstance(cite_separator, str)
     cites = {}
-    look = ['\\cite*{', '\\citet*{', '\\citep*{', '\\cite{', '\\citet{', '\\citep{', '\\newcite{','\\newcite*{']
+    look = ['\\cite*{', '\\citet*{', '\\citep*{', '\\cite{', '\\citet{', '\\citep{', '\\newcite{', '\\newcite*{']
     k = -1
     while True:
         run_j = ''
@@ -314,9 +313,9 @@ def process_cite(
 
 
 def process_citeauthor(
-        s: str,
-        lang: str,
-        **kwargs
+    s: str,
+    lang: str,
+    **kwargs
 ) -> str:
     """
     Transforms all citeauthor to [cite]. For example:
@@ -356,9 +355,9 @@ def process_citeauthor(
 
 
 def replace_pydetex_tags(
-        s: str,
-        cite_format: Tuple[str, str] = ('[', ']'),
-        **kwargs
+    s: str,
+    cite_format: Tuple[str, str] = ('[', ']'),
+    **kwargs
 ) -> str:
     """
     Replaces tags to text.
@@ -434,28 +433,6 @@ def process_ref(s: str, **kwargs) -> str:
                 break
 
 
-def process_quotes(s: str, **kwargs) -> str:
-    """
-    Process quotes.
-
-    :param s: Latex string code
-    :return: String with "quotes"
-    """
-    while True:
-        k = find_str(s, ['\\quotes{', '\\doublequotes{', '\\enquote{'])
-        if k == -1:
-            if kwargs.get('pb'):  # Update progressbar
-                kwargs.get('pb').update('Processing quotes')
-            return s
-        m = 0
-        for j in range(len(s)):
-            if s[k + j] == '{':
-                m = j
-            if s[k + j] == '}':
-                s = s[:k] + '"' + s[k + m + 1:k + j] + '"' + s[k + j + 1:]
-                break
-
-
 def remove_comments(s: str, **kwargs) -> str:
     """
     Remove comments from text.
@@ -603,9 +580,9 @@ def _load_file_search(tex_file: str, print_error: bool = False) -> str:
 
 
 def process_inputs(
-        s: str,
-        clear_not_found_files: bool = False,
-        **kwargs
+    s: str,
+    clear_not_found_files: bool = False,
+    **kwargs
 ) -> str:
     """
     Process inputs, which find the input files and retrieve its contents.
@@ -700,8 +677,8 @@ def remove_equations(s: str, **kwargs) -> str:
 
 
 def output_text_for_some_commands(
-        s: str,
-        lang: str
+    s: str,
+    lang: str
 ) -> str:
     """
     Replaces the command for a particular text.
@@ -723,18 +700,31 @@ def output_text_for_some_commands(
     # The font format is like .... [font tag]YOUR TAG {[font content]YOUR CONTENT} ...[font normal]. In that case, tag to be
     # relaced is 'YOUR TAG {0}, {1}
     # All *arguments will be formatted using the tag
-    commands: List[Tuple[str, List[Tuple[int, bool]], str, int, Optional[str], Optional[str], Tuple[bool, bool]]] = [
+    commands: List[Tuple[str, List[Tuple[int, bool]], Union[str, Callable[[str, ...], str]], int, Optional[str], Optional[str], Tuple[bool, bool]]] = [
+        ('ac', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False)),  # Acronym
+        ('acf', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False)),  # Acronym
+        ('acl', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False)),  # Acronym
+        ('acs', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False)),  # Acronym
         ('caption', [(1, False)], LANG_TT_TAGS.get(lang, 'caption'), 1, None, None, (False, True)),
         ('chapter', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
         ('chapter*', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
+        ('doublequotes', [(1, False)], lambda t: '"{0}"'.format(t), 1, 'normal', 'normal', (False, False)),
         ('em', [(1, False)], '{0}', 1, 'normal', 'bold', (False, False)),
         ('emph', [(1, False)], '{0}', 1, 'normal', 'italic', (False, False)),
+        ('enquote', [(1, False)], lambda t: '"{0}"'.format(t), 1, 'normal', 'normal', (False, False)),
         ('href', [(2, False)], LANG_TT_TAGS.get(lang, 'link'), 2, None, None, (False, False)),
-        ('insertimage', [(3, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 3, None, None, (False, True)),
-        ('insertimage', [(4, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 4, None, None, (False, False)),
-        ('insertimageboxed', [(4, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 4, None, None, (False, True)),
-        ('insertimageboxed', [(5, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 5, None, None, (False, True)),
+        ('insertimage', [(3, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 3, None, None, (False, True)),  # (Template) Informe
+        ('insertimage', [(4, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 4, None, None, (False, False)),  # (Template) Informe
+        ('insertimageboxed', [(4, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 4, None, None, (False, True)),  # (Template) Informe
+        ('insertimageboxed', [(5, False)], LANG_TT_TAGS.get(lang, 'figure_caption'), 5, None, None, (False, True)),  # (Template) Informe
+        ('institutionentry', [(1, False), (2, False), (3, False), (4, False)], '{0} ({1}-{2}). {3}', 4, 'normal', 'normal', (False, False)),  # (Template) Professional-CV
+        ('institutionentryshort', [(1, False), (2, False), (3, False), (4, False)], '{0} ({1}-{2}). {3}', 4, 'normal', 'normal', (False, False)),  # (Template) Professional-CV
+        ('lowercase', [(1, False)], lambda t: t.lower(), 1, 'normal', 'normal', (False, False)),
+        ('MakeLowercase', [(1, False)], lambda t: t.lower(), 1, 'normal', 'normal', (False, False)),
+        ('MakeUppercase', [(1, False)], lambda t: t.upper(), 1, 'normal', 'normal', (False, False)),
+        ('otherentry', [(1, False), (2, False)], '{0} {1}', 2, 'normal', 'normal', (False, False)),  # (Template) Professional-CV
         ('paragraph', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
+        ('quotes', [(1, False)], lambda t: '"{0}"'.format(t), 1, 'normal', 'normal', (False, False)),
         ('section', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
         ('section*', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
         ('subfloat', [(1, True)], LANG_TT_TAGS.get(lang, 'sub_figure_title'), 1, None, None, (False, True)),
@@ -747,7 +737,8 @@ def output_text_for_some_commands(
         ('subsubsubsection*', [(1, False)], '{0}', 1, 'normal', 'bold', (True, True)),
         ('textbf', [(1, False)], '{0}', 1, 'normal', 'bold', (False, False)),
         ('textit', [(1, False)], '{0}', 1, 'normal', 'italic', (False, False)),
-        ('texttt', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False))
+        ('texttt', [(1, False)], '{0}', 1, 'normal', 'normal', (False, False)),
+        ('uppercase', [(1, False)], lambda t: t.upper(), 1, 'normal', 'normal', (False, False))
     ]
     new_s = ''
 
@@ -775,7 +766,13 @@ def output_text_for_some_commands(
                         # Add format text
                         for a in range(len(args)):
                             args[a] = FONT_FORMAT_SETTINGS[font_content] + args[a] + FONT_FORMAT_SETTINGS[font_tag]
-                        text = cmd_tag.format(*args)
+                        if callable(cmd_tag):
+                            text = cmd_tag(*args)
+                        else:
+                            try:
+                                text = cmd_tag.format(*args)
+                            except IndexError:
+                                text = cmd_tag
                         text = FONT_FORMAT_SETTINGS[font_tag] + text + FONT_FORMAT_SETTINGS['normal']
                         if cmd_newline[0]:
                             text = _TAG_NEW_LINE + text
@@ -788,9 +785,9 @@ def output_text_for_some_commands(
 
 
 def remove_environments(
-        s: str,
-        env_list: Optional[List[str]] = None,
-        **kwargs
+    s: str,
+    env_list: Optional[List[str]] = None,
+    **kwargs
 ) -> str:
     """
     Remove a selection of environments.
@@ -854,10 +851,10 @@ def remove_environments(
 
 
 def remove_commands_param(
-        s: str,
-        lang: str,
-        invalid_commands: Optional[List[str]] = None,
-        **kwargs
+    s: str,
+    lang: str,
+    invalid_commands: Optional[List[str]] = None,
+    **kwargs
 ) -> str:
     """
     Remove all commands with params.
@@ -1005,10 +1002,10 @@ def unicode_chars_equations(s: str, **kwargs) -> str:
 
 
 def process_chars_equations(
-        s: str,
-        lang: str,
-        single_only: bool,
-        **kwargs
+    s: str,
+    lang: str,
+    single_only: bool,
+    **kwargs
 ) -> str:
     """
     Process single char equations, removing the symbols.
@@ -1080,10 +1077,10 @@ def strip_punctuation(s: str, **kwargs) -> str:
 
 
 def process_def(
-        s: str,
-        clear_learned: bool = True,
-        replace: bool = False,
-        **kwargs
+    s: str,
+    clear_learned: bool = True,
+    replace: bool = False,
+    **kwargs
 ) -> str:
     """
     Process \defs. Store the definition, among others.
@@ -1164,11 +1161,12 @@ def process_def(
     return new_s
 
 
-def process_items(s: str, **kwargs) -> str:
+def process_items(s: str, lang: str, **kwargs) -> str:
     """
     Process itemize and enumerate.
 
     :param s: Latex string code
+    :param lang: Language tag
     :return: Processed items
     """
     if not ('itemize' in s or 'enumerate' in s or 'tablenotes' in s):
@@ -1227,7 +1225,7 @@ def process_items(s: str, **kwargs) -> str:
             t = _get_name(t)
             if t == '':
                 continue
-            s = s[0:a] + _process_item(s[b:c].strip(), t) + s[d + 2:]
+            s = s[0:a] + remove_commands_param(_process_item(s[b:c].strip(), t), lang) + s[d + 2:]
             conv = True
             break
         if not conv:
